/*
 * Copyright (C) 2011 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
 * Copyright (C) 2012 David Goulet <dgoulet@efficios.com>
 *
 * SPDX-License-Identifier: MIT
 */

#define _LGPL_SOURCE
#define TRACEPOINT_CREATE_PROBES
#include "ust_gen_nevents.h"
